@@ -509,7 +509,7 @@ class GeoArray(object):
                     self._footprint_poly = self.box.mapPoly
 
             # validation
-            assert not polyVertices_outside_poly(self._footprint_poly, self.box.mapPoly), \
+            assert not polyVertices_outside_poly(self._footprint_poly, self.box.mapPoly, tolerance=1e-5), \
                 "Computing footprint polygon for %s '%s' failed. The resulting polygon is partly or completely " \
                 "outside of the image bounds." % (self.__class__.__name__, self.basename)
             # assert self._footprint_poly
