@@ -2,16 +2,13 @@
 
 context_dir="./context"
 dockerfile="geoarray_ci.docker"
-tag="geoarray_ci:latest"
-gitlab_runner="danschef_gitlab_CI_runner"
-
-# get py_tools_ds project # TODO move this to setup.py as soon as package is public
-rm -rf context/py_tools_ds
-git clone https://gitext.gfz-potsdam.de/danschef/py_tools_ds.git ./context/py_tools_ds
+tag="geoarray_ci:0.8.0"
+gitlab_runner="geoarray_gitlab_CI_runner"
 
 echo "#### Build runner docker image"
 sudo docker rmi ${tag}
-sudo docker build -f ${context_dir}/${dockerfile} -m 20G -t ${tag} ${context_dir}
+#sudo docker build -f ${context_dir}/${dockerfile} -m 20G -t ${tag} ${context_dir}
+sudo docker build --no-cache -f ${context_dir}/${dockerfile} -m 20G -t ${tag} ${context_dir}
 
 echo "#### Create gitlab-runner (daemon) container with tag; ${tag}"
 sudo docker stop ${gitlab_runner}
